# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zeebe_grpc/gateway.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18zeebe_grpc/gateway.proto\x12\x10gateway_protocol\"u\n\x1aStreamActivatedJobsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06worker\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x15\n\rfetchVariable\x18\x05 \x03(\t\x12\x11\n\ttenantIds\x18\x06 \x03(\t\"\xa1\x01\n\x13\x41\x63tivateJobsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06worker\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x19\n\x11maxJobsToActivate\x18\x04 \x01(\x05\x12\x15\n\rfetchVariable\x18\x05 \x03(\t\x12\x16\n\x0erequestTimeout\x18\x06 \x01(\x03\x12\x11\n\ttenantIds\x18\x07 \x03(\t\"D\n\x14\x41\x63tivateJobsResponse\x12,\n\x04jobs\x18\x01 \x03(\x0b\x32\x1e.gateway_protocol.ActivatedJob\"\xba\x02\n\x0c\x41\x63tivatedJob\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x1a\n\x12processInstanceKey\x18\x03 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x04 \x01(\t\x12 \n\x18processDefinitionVersion\x18\x05 \x01(\x05\x12\x1c\n\x14processDefinitionKey\x18\x06 \x01(\x03\x12\x11\n\telementId\x18\x07 \x01(\t\x12\x1a\n\x12\x65lementInstanceKey\x18\x08 \x01(\x03\x12\x15\n\rcustomHeaders\x18\t \x01(\t\x12\x0e\n\x06worker\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x10\n\x08\x64\x65\x61\x64line\x18\x0c \x01(\x03\x12\x11\n\tvariables\x18\r \x01(\t\x12\x10\n\x08tenantId\x18\x0e \x01(\t\":\n\x1c\x43\x61ncelProcessInstanceRequest\x12\x1a\n\x12processInstanceKey\x18\x01 \x01(\x03\"\x1f\n\x1d\x43\x61ncelProcessInstanceResponse\"7\n\x12\x43ompleteJobRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x11\n\tvariables\x18\x02 \x01(\t\"\x15\n\x13\x43ompleteJobResponse\"\xdf\x01\n\x1c\x43reateProcessInstanceRequest\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x11\n\tvariables\x18\x04 \x01(\t\x12T\n\x11startInstructions\x18\x05 \x03(\x0b\x32\x39.gateway_protocol.ProcessInstanceCreationStartInstruction\x12\x10\n\x08tenantId\x18\x06 \x01(\t\"<\n\'ProcessInstanceCreationStartInstruction\x12\x11\n\telementId\x18\x01 \x01(\t\"\x93\x01\n\x1d\x43reateProcessInstanceResponse\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1a\n\x12processInstanceKey\x18\x04 \x01(\x03\x12\x10\n\x08tenantId\x18\x05 \x01(\t\"\x99\x01\n&CreateProcessInstanceWithResultRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32..gateway_protocol.CreateProcessInstanceRequest\x12\x16\n\x0erequestTimeout\x18\x02 \x01(\x03\x12\x16\n\x0e\x66\x65tchVariables\x18\x03 \x03(\t\"\xb0\x01\n\'CreateProcessInstanceWithResultResponse\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1a\n\x12processInstanceKey\x18\x04 \x01(\x03\x12\x11\n\tvariables\x18\x05 \x01(\t\x12\x10\n\x08tenantId\x18\x06 \x01(\t\"g\n\x17\x45valuateDecisionRequest\x12\x13\n\x0b\x64\x65\x63isionKey\x18\x01 \x01(\x03\x12\x12\n\ndecisionId\x18\x02 \x01(\t\x12\x11\n\tvariables\x18\x03 \x01(\t\x12\x10\n\x08tenantId\x18\x04 \x01(\t\"\xd0\x02\n\x18\x45valuateDecisionResponse\x12\x13\n\x0b\x64\x65\x63isionKey\x18\x01 \x01(\x03\x12\x12\n\ndecisionId\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65\x63isionName\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65\x63isionVersion\x18\x04 \x01(\x05\x12\x1e\n\x16\x64\x65\x63isionRequirementsId\x18\x05 \x01(\t\x12\x1f\n\x17\x64\x65\x63isionRequirementsKey\x18\x06 \x01(\x03\x12\x16\n\x0e\x64\x65\x63isionOutput\x18\x07 \x01(\t\x12?\n\x12\x65valuatedDecisions\x18\x08 \x03(\x0b\x32#.gateway_protocol.EvaluatedDecision\x12\x18\n\x10\x66\x61iledDecisionId\x18\t \x01(\t\x12\x16\n\x0e\x66\x61ilureMessage\x18\n \x01(\t\x12\x10\n\x08tenantId\x18\x0b \x01(\t\"\xab\x02\n\x11\x45valuatedDecision\x12\x13\n\x0b\x64\x65\x63isionKey\x18\x01 \x01(\x03\x12\x12\n\ndecisionId\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x65\x63isionName\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65\x63isionVersion\x18\x04 \x01(\x05\x12\x14\n\x0c\x64\x65\x63isionType\x18\x05 \x01(\t\x12\x16\n\x0e\x64\x65\x63isionOutput\x18\x06 \x01(\t\x12;\n\x0cmatchedRules\x18\x07 \x03(\x0b\x32%.gateway_protocol.MatchedDecisionRule\x12\x41\n\x0f\x65valuatedInputs\x18\x08 \x03(\x0b\x32(.gateway_protocol.EvaluatedDecisionInput\x12\x10\n\x08tenantId\x18\t \x01(\t\"P\n\x16\x45valuatedDecisionInput\x12\x0f\n\x07inputId\x18\x01 \x01(\t\x12\x11\n\tinputName\x18\x02 \x01(\t\x12\x12\n\ninputValue\x18\x03 \x01(\t\"T\n\x17\x45valuatedDecisionOutput\x12\x10\n\x08outputId\x18\x01 \x01(\t\x12\x12\n\noutputName\x18\x02 \x01(\t\x12\x13\n\x0boutputValue\x18\x03 \x01(\t\"}\n\x13MatchedDecisionRule\x12\x0e\n\x06ruleId\x18\x01 \x01(\t\x12\x11\n\truleIndex\x18\x02 \x01(\x05\x12\x43\n\x10\x65valuatedOutputs\x18\x03 \x03(\x0b\x32).gateway_protocol.EvaluatedDecisionOutput\"U\n\x14\x44\x65ployProcessRequest\x12\x39\n\tprocesses\x18\x01 \x03(\x0b\x32&.gateway_protocol.ProcessRequestObject:\x02\x18\x01\"<\n\x14ProcessRequestObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\x0c:\x02\x18\x01\"^\n\x15\x44\x65ployProcessResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x34\n\tprocesses\x18\x02 \x03(\x0b\x32!.gateway_protocol.ProcessMetadata:\x02\x18\x01\"X\n\x15\x44\x65ployResourceRequest\x12-\n\tresources\x18\x01 \x03(\x0b\x32\x1a.gateway_protocol.Resource\x12\x10\n\x08tenantId\x18\x02 \x01(\t\")\n\x08Resource\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"j\n\x16\x44\x65ployResourceResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x31\n\x0b\x64\x65ployments\x18\x02 \x03(\x0b\x32\x1c.gateway_protocol.Deployment\x12\x10\n\x08tenantId\x18\x03 \x01(\t\"\x86\x02\n\nDeployment\x12\x34\n\x07process\x18\x01 \x01(\x0b\x32!.gateway_protocol.ProcessMetadataH\x00\x12\x36\n\x08\x64\x65\x63ision\x18\x02 \x01(\x0b\x32\".gateway_protocol.DecisionMetadataH\x00\x12N\n\x14\x64\x65\x63isionRequirements\x18\x03 \x01(\x0b\x32..gateway_protocol.DecisionRequirementsMetadataH\x00\x12.\n\x04\x66orm\x18\x04 \x01(\x0b\x32\x1e.gateway_protocol.FormMetadataH\x00\x42\n\n\x08Metadata\"\x7f\n\x0fProcessMetadata\x12\x15\n\rbpmnProcessId\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x1c\n\x14processDefinitionKey\x18\x03 \x01(\x03\x12\x14\n\x0cresourceName\x18\x04 \x01(\t\x12\x10\n\x08tenantId\x18\x05 \x01(\t\"\xbe\x01\n\x10\x44\x65\x63isionMetadata\x12\x15\n\rdmnDecisionId\x18\x01 \x01(\t\x12\x17\n\x0f\x64mnDecisionName\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x13\n\x0b\x64\x65\x63isionKey\x18\x04 \x01(\x03\x12!\n\x19\x64mnDecisionRequirementsId\x18\x05 \x01(\t\x12\x1f\n\x17\x64\x65\x63isionRequirementsKey\x18\x06 \x01(\x03\x12\x10\n\x08tenantId\x18\x07 \x01(\t\"\xc0\x01\n\x1c\x44\x65\x63isionRequirementsMetadata\x12!\n\x19\x64mnDecisionRequirementsId\x18\x01 \x01(\t\x12#\n\x1b\x64mnDecisionRequirementsName\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1f\n\x17\x64\x65\x63isionRequirementsKey\x18\x04 \x01(\x03\x12\x14\n\x0cresourceName\x18\x05 \x01(\t\x12\x10\n\x08tenantId\x18\x06 \x01(\t\"h\n\x0c\x46ormMetadata\x12\x0e\n\x06\x66ormId\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x0f\n\x07\x66ormKey\x18\x03 \x01(\x03\x12\x14\n\x0cresourceName\x18\x04 \x01(\t\x12\x10\n\x08tenantId\x18\x05 \x01(\t\"p\n\x0e\x46\x61ilJobRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x0f\n\x07retries\x18\x02 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x14\n\x0cretryBackOff\x18\x04 \x01(\x03\x12\x11\n\tvariables\x18\x05 \x01(\t\"\x11\n\x0f\x46\x61ilJobResponse\"_\n\x11ThrowErrorRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x11\n\terrorCode\x18\x02 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x11\n\tvariables\x18\x04 \x01(\t\"\x14\n\x12ThrowErrorResponse\"\x89\x01\n\x15PublishMessageRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x63orrelationKey\x18\x02 \x01(\t\x12\x12\n\ntimeToLive\x18\x03 \x01(\x03\x12\x11\n\tmessageId\x18\x04 \x01(\t\x12\x11\n\tvariables\x18\x05 \x01(\t\x12\x10\n\x08tenantId\x18\x06 \x01(\t\"7\n\x16PublishMessageResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x10\n\x08tenantId\x18\x02 \x01(\t\"-\n\x16ResolveIncidentRequest\x12\x13\n\x0bincidentKey\x18\x01 \x01(\x03\"\x19\n\x17ResolveIncidentResponse\"\x11\n\x0fTopologyRequest\"\xa2\x01\n\x10TopologyResponse\x12-\n\x07\x62rokers\x18\x01 \x03(\x0b\x32\x1c.gateway_protocol.BrokerInfo\x12\x13\n\x0b\x63lusterSize\x18\x02 \x01(\x05\x12\x17\n\x0fpartitionsCount\x18\x03 \x01(\x05\x12\x19\n\x11replicationFactor\x18\x04 \x01(\x05\x12\x16\n\x0egatewayVersion\x18\x05 \x01(\t\"z\n\nBrokerInfo\x12\x0e\n\x06nodeId\x18\x01 \x01(\x05\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12/\n\npartitions\x18\x04 \x03(\x0b\x32\x1b.gateway_protocol.Partition\x12\x0f\n\x07version\x18\x05 \x01(\t\"\xa0\x02\n\tPartition\x12\x13\n\x0bpartitionId\x18\x01 \x01(\x05\x12=\n\x04role\x18\x02 \x01(\x0e\x32/.gateway_protocol.Partition.PartitionBrokerRole\x12\x41\n\x06health\x18\x03 \x01(\x0e\x32\x31.gateway_protocol.Partition.PartitionBrokerHealth\"=\n\x13PartitionBrokerRole\x12\n\n\x06LEADER\x10\x00\x12\x0c\n\x08\x46OLLOWER\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\"=\n\x15PartitionBrokerHealth\x12\x0b\n\x07HEALTHY\x10\x00\x12\r\n\tUNHEALTHY\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\":\n\x17UpdateJobRetriesRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x0f\n\x07retries\x18\x02 \x01(\x05\"\x1a\n\x18UpdateJobRetriesResponse\"S\n\x13SetVariablesRequest\x12\x1a\n\x12\x65lementInstanceKey\x18\x01 \x01(\x03\x12\x11\n\tvariables\x18\x02 \x01(\t\x12\r\n\x05local\x18\x03 \x01(\x08\"#\n\x14SetVariablesResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\"\xa0\x04\n\x1cModifyProcessInstanceRequest\x12\x1a\n\x12processInstanceKey\x18\x01 \x01(\x03\x12`\n\x14\x61\x63tivateInstructions\x18\x02 \x03(\x0b\x32\x42.gateway_protocol.ModifyProcessInstanceRequest.ActivateInstruction\x12\x62\n\x15terminateInstructions\x18\x03 \x03(\x0b\x32\x43.gateway_protocol.ModifyProcessInstanceRequest.TerminateInstruction\x1a\xae\x01\n\x13\x41\x63tivateInstruction\x12\x11\n\telementId\x18\x01 \x01(\t\x12\"\n\x1a\x61ncestorElementInstanceKey\x18\x02 \x01(\x03\x12`\n\x14variableInstructions\x18\x03 \x03(\x0b\x32\x42.gateway_protocol.ModifyProcessInstanceRequest.VariableInstruction\x1a\x39\n\x13VariableInstruction\x12\x11\n\tvariables\x18\x01 \x01(\t\x12\x0f\n\x07scopeId\x18\x02 \x01(\t\x1a\x32\n\x14TerminateInstruction\x12\x1a\n\x12\x65lementInstanceKey\x18\x01 \x01(\x03\"\x1f\n\x1dModifyProcessInstanceResponse\",\n\x15\x44\x65leteResourceRequest\x12\x13\n\x0bresourceKey\x18\x01 \x01(\x03\"\x18\n\x16\x44\x65leteResourceResponse\"?\n\x16\x42roadcastSignalRequest\x12\x12\n\nsignalName\x18\x01 \x01(\t\x12\x11\n\tvariables\x18\x02 \x01(\t\"&\n\x17\x42roadcastSignalResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x32\xef\x0f\n\x07Gateway\x12\x61\n\x0c\x41\x63tivateJobs\x12%.gateway_protocol.ActivateJobsRequest\x1a&.gateway_protocol.ActivateJobsResponse\"\x00\x30\x01\x12g\n\x13StreamActivatedJobs\x12,.gateway_protocol.StreamActivatedJobsRequest\x1a\x1e.gateway_protocol.ActivatedJob\"\x00\x30\x01\x12z\n\x15\x43\x61ncelProcessInstance\x12..gateway_protocol.CancelProcessInstanceRequest\x1a/.gateway_protocol.CancelProcessInstanceResponse\"\x00\x12\\\n\x0b\x43ompleteJob\x12$.gateway_protocol.CompleteJobRequest\x1a%.gateway_protocol.CompleteJobResponse\"\x00\x12z\n\x15\x43reateProcessInstance\x12..gateway_protocol.CreateProcessInstanceRequest\x1a/.gateway_protocol.CreateProcessInstanceResponse\"\x00\x12\x98\x01\n\x1f\x43reateProcessInstanceWithResult\x12\x38.gateway_protocol.CreateProcessInstanceWithResultRequest\x1a\x39.gateway_protocol.CreateProcessInstanceWithResultResponse\"\x00\x12k\n\x10\x45valuateDecision\x12).gateway_protocol.EvaluateDecisionRequest\x1a*.gateway_protocol.EvaluateDecisionResponse\"\x00\x12\x65\n\rDeployProcess\x12&.gateway_protocol.DeployProcessRequest\x1a\'.gateway_protocol.DeployProcessResponse\"\x03\x88\x02\x01\x12\x65\n\x0e\x44\x65ployResource\x12\'.gateway_protocol.DeployResourceRequest\x1a(.gateway_protocol.DeployResourceResponse\"\x00\x12P\n\x07\x46\x61ilJob\x12 .gateway_protocol.FailJobRequest\x1a!.gateway_protocol.FailJobResponse\"\x00\x12Y\n\nThrowError\x12#.gateway_protocol.ThrowErrorRequest\x1a$.gateway_protocol.ThrowErrorResponse\"\x00\x12\x65\n\x0ePublishMessage\x12\'.gateway_protocol.PublishMessageRequest\x1a(.gateway_protocol.PublishMessageResponse\"\x00\x12h\n\x0fResolveIncident\x12(.gateway_protocol.ResolveIncidentRequest\x1a).gateway_protocol.ResolveIncidentResponse\"\x00\x12_\n\x0cSetVariables\x12%.gateway_protocol.SetVariablesRequest\x1a&.gateway_protocol.SetVariablesResponse\"\x00\x12S\n\x08Topology\x12!.gateway_protocol.TopologyRequest\x1a\".gateway_protocol.TopologyResponse\"\x00\x12k\n\x10UpdateJobRetries\x12).gateway_protocol.UpdateJobRetriesRequest\x1a*.gateway_protocol.UpdateJobRetriesResponse\"\x00\x12z\n\x15ModifyProcessInstance\x12..gateway_protocol.ModifyProcessInstanceRequest\x1a/.gateway_protocol.ModifyProcessInstanceResponse\"\x00\x12\x65\n\x0e\x44\x65leteResource\x12\'.gateway_protocol.DeleteResourceRequest\x1a(.gateway_protocol.DeleteResourceResponse\"\x00\x12h\n\x0f\x42roadcastSignal\x12(.gateway_protocol.BroadcastSignalRequest\x1a).gateway_protocol.BroadcastSignalResponse\"\x00\x42,\n!io.camunda.zeebe.gateway.protocolP\x00Z\x05./;pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zeebe_grpc.gateway_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!io.camunda.zeebe.gateway.protocolP\000Z\005./;pb'
  _globals['_DEPLOYPROCESSREQUEST']._options = None
  _globals['_DEPLOYPROCESSREQUEST']._serialized_options = b'\030\001'
  _globals['_PROCESSREQUESTOBJECT']._options = None
  _globals['_PROCESSREQUESTOBJECT']._serialized_options = b'\030\001'
  _globals['_DEPLOYPROCESSRESPONSE']._options = None
  _globals['_DEPLOYPROCESSRESPONSE']._serialized_options = b'\030\001'
  _globals['_GATEWAY'].methods_by_name['DeployProcess']._options = None
  _globals['_GATEWAY'].methods_by_name['DeployProcess']._serialized_options = b'\210\002\001'
  _globals['_STREAMACTIVATEDJOBSREQUEST']._serialized_start=46
  _globals['_STREAMACTIVATEDJOBSREQUEST']._serialized_end=163
  _globals['_ACTIVATEJOBSREQUEST']._serialized_start=166
  _globals['_ACTIVATEJOBSREQUEST']._serialized_end=327
  _globals['_ACTIVATEJOBSRESPONSE']._serialized_start=329
  _globals['_ACTIVATEJOBSRESPONSE']._serialized_end=397
  _globals['_ACTIVATEDJOB']._serialized_start=400
  _globals['_ACTIVATEDJOB']._serialized_end=714
  _globals['_CANCELPROCESSINSTANCEREQUEST']._serialized_start=716
  _globals['_CANCELPROCESSINSTANCEREQUEST']._serialized_end=774
  _globals['_CANCELPROCESSINSTANCERESPONSE']._serialized_start=776
  _globals['_CANCELPROCESSINSTANCERESPONSE']._serialized_end=807
  _globals['_COMPLETEJOBREQUEST']._serialized_start=809
  _globals['_COMPLETEJOBREQUEST']._serialized_end=864
  _globals['_COMPLETEJOBRESPONSE']._serialized_start=866
  _globals['_COMPLETEJOBRESPONSE']._serialized_end=887
  _globals['_CREATEPROCESSINSTANCEREQUEST']._serialized_start=890
  _globals['_CREATEPROCESSINSTANCEREQUEST']._serialized_end=1113
  _globals['_PROCESSINSTANCECREATIONSTARTINSTRUCTION']._serialized_start=1115
  _globals['_PROCESSINSTANCECREATIONSTARTINSTRUCTION']._serialized_end=1175
  _globals['_CREATEPROCESSINSTANCERESPONSE']._serialized_start=1178
  _globals['_CREATEPROCESSINSTANCERESPONSE']._serialized_end=1325
  _globals['_CREATEPROCESSINSTANCEWITHRESULTREQUEST']._serialized_start=1328
  _globals['_CREATEPROCESSINSTANCEWITHRESULTREQUEST']._serialized_end=1481
  _globals['_CREATEPROCESSINSTANCEWITHRESULTRESPONSE']._serialized_start=1484
  _globals['_CREATEPROCESSINSTANCEWITHRESULTRESPONSE']._serialized_end=1660
  _globals['_EVALUATEDECISIONREQUEST']._serialized_start=1662
  _globals['_EVALUATEDECISIONREQUEST']._serialized_end=1765
  _globals['_EVALUATEDECISIONRESPONSE']._serialized_start=1768
  _globals['_EVALUATEDECISIONRESPONSE']._serialized_end=2104
  _globals['_EVALUATEDDECISION']._serialized_start=2107
  _globals['_EVALUATEDDECISION']._serialized_end=2406
  _globals['_EVALUATEDDECISIONINPUT']._serialized_start=2408
  _globals['_EVALUATEDDECISIONINPUT']._serialized_end=2488
  _globals['_EVALUATEDDECISIONOUTPUT']._serialized_start=2490
  _globals['_EVALUATEDDECISIONOUTPUT']._serialized_end=2574
  _globals['_MATCHEDDECISIONRULE']._serialized_start=2576
  _globals['_MATCHEDDECISIONRULE']._serialized_end=2701
  _globals['_DEPLOYPROCESSREQUEST']._serialized_start=2703
  _globals['_DEPLOYPROCESSREQUEST']._serialized_end=2788
  _globals['_PROCESSREQUESTOBJECT']._serialized_start=2790
  _globals['_PROCESSREQUESTOBJECT']._serialized_end=2850
  _globals['_DEPLOYPROCESSRESPONSE']._serialized_start=2852
  _globals['_DEPLOYPROCESSRESPONSE']._serialized_end=2946
  _globals['_DEPLOYRESOURCEREQUEST']._serialized_start=2948
  _globals['_DEPLOYRESOURCEREQUEST']._serialized_end=3036
  _globals['_RESOURCE']._serialized_start=3038
  _globals['_RESOURCE']._serialized_end=3079
  _globals['_DEPLOYRESOURCERESPONSE']._serialized_start=3081
  _globals['_DEPLOYRESOURCERESPONSE']._serialized_end=3187
  _globals['_DEPLOYMENT']._serialized_start=3190
  _globals['_DEPLOYMENT']._serialized_end=3452
  _globals['_PROCESSMETADATA']._serialized_start=3454
  _globals['_PROCESSMETADATA']._serialized_end=3581
  _globals['_DECISIONMETADATA']._serialized_start=3584
  _globals['_DECISIONMETADATA']._serialized_end=3774
  _globals['_DECISIONREQUIREMENTSMETADATA']._serialized_start=3777
  _globals['_DECISIONREQUIREMENTSMETADATA']._serialized_end=3969
  _globals['_FORMMETADATA']._serialized_start=3971
  _globals['_FORMMETADATA']._serialized_end=4075
  _globals['_FAILJOBREQUEST']._serialized_start=4077
  _globals['_FAILJOBREQUEST']._serialized_end=4189
  _globals['_FAILJOBRESPONSE']._serialized_start=4191
  _globals['_FAILJOBRESPONSE']._serialized_end=4208
  _globals['_THROWERRORREQUEST']._serialized_start=4210
  _globals['_THROWERRORREQUEST']._serialized_end=4305
  _globals['_THROWERRORRESPONSE']._serialized_start=4307
  _globals['_THROWERRORRESPONSE']._serialized_end=4327
  _globals['_PUBLISHMESSAGEREQUEST']._serialized_start=4330
  _globals['_PUBLISHMESSAGEREQUEST']._serialized_end=4467
  _globals['_PUBLISHMESSAGERESPONSE']._serialized_start=4469
  _globals['_PUBLISHMESSAGERESPONSE']._serialized_end=4524
  _globals['_RESOLVEINCIDENTREQUEST']._serialized_start=4526
  _globals['_RESOLVEINCIDENTREQUEST']._serialized_end=4571
  _globals['_RESOLVEINCIDENTRESPONSE']._serialized_start=4573
  _globals['_RESOLVEINCIDENTRESPONSE']._serialized_end=4598
  _globals['_TOPOLOGYREQUEST']._serialized_start=4600
  _globals['_TOPOLOGYREQUEST']._serialized_end=4617
  _globals['_TOPOLOGYRESPONSE']._serialized_start=4620
  _globals['_TOPOLOGYRESPONSE']._serialized_end=4782
  _globals['_BROKERINFO']._serialized_start=4784
  _globals['_BROKERINFO']._serialized_end=4906
  _globals['_PARTITION']._serialized_start=4909
  _globals['_PARTITION']._serialized_end=5197
  _globals['_PARTITION_PARTITIONBROKERROLE']._serialized_start=5073
  _globals['_PARTITION_PARTITIONBROKERROLE']._serialized_end=5134
  _globals['_PARTITION_PARTITIONBROKERHEALTH']._serialized_start=5136
  _globals['_PARTITION_PARTITIONBROKERHEALTH']._serialized_end=5197
  _globals['_UPDATEJOBRETRIESREQUEST']._serialized_start=5199
  _globals['_UPDATEJOBRETRIESREQUEST']._serialized_end=5257
  _globals['_UPDATEJOBRETRIESRESPONSE']._serialized_start=5259
  _globals['_UPDATEJOBRETRIESRESPONSE']._serialized_end=5285
  _globals['_SETVARIABLESREQUEST']._serialized_start=5287
  _globals['_SETVARIABLESREQUEST']._serialized_end=5370
  _globals['_SETVARIABLESRESPONSE']._serialized_start=5372
  _globals['_SETVARIABLESRESPONSE']._serialized_end=5407
  _globals['_MODIFYPROCESSINSTANCEREQUEST']._serialized_start=5410
  _globals['_MODIFYPROCESSINSTANCEREQUEST']._serialized_end=5954
  _globals['_MODIFYPROCESSINSTANCEREQUEST_ACTIVATEINSTRUCTION']._serialized_start=5669
  _globals['_MODIFYPROCESSINSTANCEREQUEST_ACTIVATEINSTRUCTION']._serialized_end=5843
  _globals['_MODIFYPROCESSINSTANCEREQUEST_VARIABLEINSTRUCTION']._serialized_start=5845
  _globals['_MODIFYPROCESSINSTANCEREQUEST_VARIABLEINSTRUCTION']._serialized_end=5902
  _globals['_MODIFYPROCESSINSTANCEREQUEST_TERMINATEINSTRUCTION']._serialized_start=5904
  _globals['_MODIFYPROCESSINSTANCEREQUEST_TERMINATEINSTRUCTION']._serialized_end=5954
  _globals['_MODIFYPROCESSINSTANCERESPONSE']._serialized_start=5956
  _globals['_MODIFYPROCESSINSTANCERESPONSE']._serialized_end=5987
  _globals['_DELETERESOURCEREQUEST']._serialized_start=5989
  _globals['_DELETERESOURCEREQUEST']._serialized_end=6033
  _globals['_DELETERESOURCERESPONSE']._serialized_start=6035
  _globals['_DELETERESOURCERESPONSE']._serialized_end=6059
  _globals['_BROADCASTSIGNALREQUEST']._serialized_start=6061
  _globals['_BROADCASTSIGNALREQUEST']._serialized_end=6124
  _globals['_BROADCASTSIGNALRESPONSE']._serialized_start=6126
  _globals['_BROADCASTSIGNALRESPONSE']._serialized_end=6164
  _globals['_GATEWAY']._serialized_start=6167
  _globals['_GATEWAY']._serialized_end=8198
# @@protoc_insertion_point(module_scope)
